Simplex Controls — ecyglpki 0.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- ecyglpki 0.2.0 documentation »

# Simplex Controls

class `ecyglpki.` `SimplexControls`

  The simplex solver control parameter object

      >>> r = SimplexControls()

  `it_lim`

    Iteration limit, an `int`

        >>> r.it_lim  # the GLPK default
        2147483647
        >>> r.it_lim = 10
        >>> r.it_lim
        10

  `meth`

    The simplex method, a `str`

    The possible values are

    - `'primal'`: two-phase primal simplex
    - `'dual'`: two-phase dual simplex
    - `'dual_fail_primal'`: two-phase dual simplex and, if it fails, switch to primal simplex

        >>> r.meth  # the GLPK default
        'primal'
        >>> r.meth = 'dual_fail_primal'
        >>> r.meth
        'dual_fail_primal'

  `msg_lev`

    The message level, a `str`

    The possible values are

    - `'no'`: no output
    - `'warnerror'`: warnings and errors only
    - `'normal'`: normal output
    - `'full'`: normal output and informational messages

        >>> r.msg_lev  # the GLPK default
        'full'
        >>> r.msg_lev = 'no'
        >>> r.msg_lev
        'no'

  `obj_ll`

    Lower limit of the objective function, a `Real` number

    (Used only if meth is `'dual'`.)

        >>> r.obj_ll  # the GLPK default
        -1.7976931348623157e+308
        >>> r.obj_ll = -1234.0
        >>> r.obj_ll
        -1234.0

  `obj_ul`

    Upper limit of the objective function, a `Real` number

    (Used only if meth is `'dual'`.)

        >>> r.obj_ul  # the GLPK default
        1.7976931348623157e+308
        >>> r.obj_ul = 123.4
        >>> r.obj_ul
        123.4

  `out_dly`

    Output delay [ms] of solution process information, an `int`

        >>> r.out_dly  # the GLPK default
        0
        >>> r.out_dly = 25
        >>> r.out_dly
        25

  `out_frq`

    Output frequency [iterations] of informational messages, an `int`

        >>> r.out_frq  # the GLPK default
        500
        >>> r.out_frq = 50
        >>> r.out_frq
        50

  `presolve`

    Whether to use the LP presolver, a `bool`

        >>> r.presolve  # the GLPK default
        False
        >>> r.presolve = True
        >>> r.presolve
        True

  `pricing`

    The pricing technique, a `str`

    The possible values are

    - `'Dantzig'`: standard ‘textbook’
    - `'steepest'`: projected steepest edge

        >>> r.pricing  # the GLPK default
        'steepest'
        >>> r.pricing = 'Dantzig'
        >>> r.pricing
        'Dantzig'

  `r_test`

    The ratio test technique, a `str`

    The possible values are

    - `'standard'`: standard ‘textbook’
    - `'Harris'`: Harris’s two-pass ratio test

        >>> r.r_test  # the GLPK default
        'Harris'
        >>> r.r_test = 'standard'
        >>> r.r_test
        'standard'

  `tm_lim`

    Time limit [ms], an `int`

        >>> r.tm_lim  # the GLPK default
        2147483647
        >>> r.tm_lim = 1e7
        >>> r.tm_lim
        10000000

  `tol_bnd`

    Tolerance to check if the solution is primal feasible, a `Real` number

        >>> r.tol_bnd  # the GLPK default
        1e-07
        >>> r.tol_bnd = 0.2
        >>> r.tol_bnd
        0.2

  `tol_dj`

    Tolerance to check if the solution is dual feasible, a `Real` number

        >>> r.tol_dj  # the GLPK default
        1e-07
        >>> r.tol_dj = 0.01
        >>> r.tol_dj
        0.01

  `tol_piv`

    Tolerance to choose eligble pivotal elements, a `Real` number

        >>> r.tol_piv  # the GLPK default
        1e-10
        >>> r.tol_piv = 1e-3
        >>> r.tol_piv
        0.001

### Navigation

- index
- modules |
- next |
- previous |
- ecyglpki 0.2.0 documentation »